# do not import dios-stuff here


class Options:
    """storage class for the keys in ``dios_options``"""

    """Set the number of rows and variables to display in a call that use
    ``__repr__`` or ``__str__`` like e.g. ``print(dios)`` do."""
    disp_max_rows = "disp_max_rows "
    disp_max_vars = "disp_max_vars"

    """
    0: accept all
    1: accept if at least one keys is is in both DioS
    3: accept if both dios have the exact same keys (makes only sense for assignments with slicer,
      otherwise its the same than creating a new dios)"""
    dios_to_dios_method = "dios_to_dios_method"

    mixed_itype_policy = "mixed_itype_policy"


class OptionsDiosToDios:
    all_must_match = 'all'
    at_least_one = 'one'
    any_matching = 'any'


# set default values
dios_options = {
    Options.disp_max_rows: 10,
    Options.disp_max_vars: 4,
    Options.dios_to_dios_method: 3,
    Options.mixed_itype_policy: 'warn',
}


def check_keys_by_policy(check, keys, policy):

    if policy == OptionsDiosToDios.any_matching:
        check = [k for k in check if k in keys]

    elif policy == OptionsDiosToDios.at_least_one:
        check = [k for k in check if k in keys]
        if not check:
            raise KeyError("policy says: at least one key must be shared.")

    elif OptionsDiosToDios.all_must_match:
        fail = set(check).symmetric_difference(set(keys))
        if fail:
            raise KeyError(f"{fail}. policy says: all keys must be present.")
    else:
        raise ValueError(policy)

    return check
